@@ -15,9 +15,10 @@
 #  limitations under the License.
 
 
+from __future__ import absolute_import
 import sys
-from utils.text import _u, get_term_size
-import cl_overriding
+from .utils.text import _u, get_term_size
+from . import cl_overriding
 
 
 class color_print(object):
@@ -139,7 +140,7 @@ class color_print(object):
         # offsetL = 0
         for color, leftString in argL:
             offsetL += self.lenString(leftString)
-            if color_dict.has_key(color):
+            if color in color_dict:
                 # печатаем и считаем смещение
                 color_dict[color](leftString)
             else:
@@ -152,7 +153,7 @@ class color_print(object):
         if offset_r:
             self.printRight(offsetL, offset_r)
             for color, rightString in argR:
-                if color_dict.has_key(color):
+                if color in color_dict:
                     # печатаем и считаем смещение
                     color_dict[color](rightString)
                 else:
