@@ -14,6 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 import sys
 import calculate.contrib.progressbar as progressbar
 
@@ -66,7 +67,7 @@ def get_progress_bar(bartype="text", title=""):
                      progressbar.Timer(
                          format="Time:%s")]).start()
     elif bartype == "gui":
-        from cl_progressbar_gui import ClProgressDialog
+        from .cl_progressbar_gui import ClProgressDialog
         if ClProgressDialog:
             pbar = ClProgressDialog()
             pbar.setCancelButton(None)
@@ -86,7 +87,7 @@ def get_message_box():
     """
     Получить message box
     """
-    from cl_progressbar_gui import ClMessageBox
+    from .cl_progressbar_gui import ClMessageBox
     if ClMessageBox:
         return ClMessageBox()
     else:
