@@ -14,8 +14,9 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 import re
-from generic import objShare
+from .generic import objShare
 from calculate.lib.cl_template import blocText
 from calculate.lib.cl_xml import xmlDoc
 
