@@ -228,7 +228,7 @@ class plasma(samba):
             if not listPath:
                 return ret
             flagList = False
-            if type(areaF) == types.ListType:
+            if type(areaF) == list:
                 fields = areaF
                 flagList = True
             else:
