@@ -14,9 +14,10 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 import re
 from calculate.lib.cl_xml import xpath
-from generic import objShare
+from .generic import objShare
 from calculate.lib.cl_xml import xmlDoc
 
 
