@@ -15,7 +15,7 @@
 #  limitations under the License.
 
 import sys
-import urllib2
+import urllib.request as urllib2
 import re
 import time
 import os
