@@ -14,8 +14,9 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 from xml.etree import ElementTree as ET
-from palette import (TextState, BaseColorMapping,
+from .palette import (TextState, BaseColorMapping,
                      ConsoleCodeMapping, LightColorMapping, ConsoleColor256,
                      ConsoleCodesInfo, SpanPalette, XmlFormat)
 
