@@ -14,6 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 import sys
 import os
 from os import path
@@ -27,7 +28,7 @@ from calculate.lib.utils.portage import (isPkgInstalled, searchProfile,
 from calculate.lib.utils.files import readFile, pathJoin
 from calculate.lib.configparser import ConfigParser
 from calculate.lib.utils.tools import unique, drop_slash
-import env
+from . import env
 
 _ = lambda x: x
 from calculate.lib.cl_lang import setLocalTranslate
